==> pmml-model-1.4.15-sources.jar: org/dmg/pmml/PMMLFunctions.java <==
/*
 * Copyright (c) 2019 Villu Ruusmann
 */
package org.dmg.pmml;

public interface PMMLFunctions {

	String ABS = "abs";
	String ACOS = "x-acos";
	String ADD = "+";
	String AND = "and";
	String ASIN = "x-asin";
	String ATAN = "x-atan";
	String ATAN2 = "x-atan2";
	String AVG = "avg";
	String CEIL = "ceil";
	String CONCAT = "concat";
	String COS = "x-cos";
	String COSH = "x-cosh";
	String DATEDAYSSINCEYEAR = "dateDaysSinceYear";
	String DATESECONDSSINCEMIDNIGHT = "dateSecondsSinceMidnight";
	String DATESECONDSSINCEYEAR = "dateSecondsSinceYear";
	String DIVIDE = "/";
	String EQUAL = "equal";
	String ERF = "erf";
	String EXP = "exp";
	String EXPM1 = "x-expm1";
	String FLOOR = "floor";
	String FORMATDATETIME = "formatDatetime";
	String FORMATNUMBER = "formatNumber";
	String GREATEROREQUAL = "greaterOrEqual";
	String GREATERTHAN = "greaterThan";
	String HYPOT = "x-hypot";
	String IF = "if";
	String ISIN = "isIn";
	String ISMISSING = "isMissing";
	String ISNOTIN = "isNotIn";
	String ISNOTMISSING = "isNotMissing";
	String LESSOREQUAL = "lessOrEqual";
	String LESSTHAN = "lessThan";
	String LN = "ln";
	String LN1P = "x-ln1p";
	String LOG10 = "log10";
	String LOWERCASE = "lowercase";
	String MATCHES = "matches";
	String MAX = "max";
	String MEDIAN = "median";
	String MIN = "min";
	String MODULO = "x-modulo";
	String MULTIPLY = "*";
	String NORMALCDF = "normalCDF";
	String NORMALIDF = "normalIDF";
	String NORMALPDF = "normalPDF";
	String NOT = "not";
	String NOTEQUAL = "notEqual";
	String OR = "or";
	String POW = "pow";
	String PRODUCT = "product";
	String REPLACE = "replace";
	String RINT = "x-rint";
	String ROUND = "round";
	String SIN = "x-sin";
	String SINH = "x-sinh";
	String SQRT = "sqrt";
	String STDNORMALCDF = "stdNormalCDF";
	String STDNORMALIDF = "stdNormalIDF";
	String STDNORMALPDF = "stdNormalPDF";
	String SUBSTRING = "substring";
	String SUBTRACT = "-";
	String SUM = "sum";
	String TAN = "x-tan";
	String TANH = "x-tanh";
	String THRESHOLD = "threshold";
	String TRIMBLANKS = "trimBlanks";
	String UPPERCASE = "uppercase";
}

==> pmml-model-1.5.2-sources.jar: org/dmg/pmml/PMMLFunctions.java <==
/*
 * Copyright (c) 2019 Villu Ruusmann
 */
package org.dmg.pmml;

public interface PMMLFunctions {

	String ABS = "abs";
	String ACOS = "acos";
	String ADD = "+";
	String AND = "and";
	String ASIN = "asin";
	String ATAN = "atan";
	String ATAN2 = "x-atan2";
	String AVG = "avg";
	String CEIL = "ceil";
	String CONCAT = "concat";
	String COS = "cos";
	String COSH = "cosh";
	String DATEDAYSSINCEYEAR = "dateDaysSinceYear";
	String DATESECONDSSINCEMIDNIGHT = "dateSecondsSinceMidnight";
	String DATESECONDSSINCEYEAR = "dateSecondsSinceYear";
	String DIVIDE = "/";
	String EQUAL = "equal";
	String ERF = "erf";
	String EXP = "exp";
	String EXPM1 = "expm1";
	String FLOOR = "floor";
	String FORMATDATETIME = "formatDatetime";
	String FORMATNUMBER = "formatNumber";
	String GREATEROREQUAL = "greaterOrEqual";
	String GREATERTHAN = "greaterThan";
	String HYPOT = "hypot";
	String IF = "if";
	String ISIN = "isIn";
	String ISMISSING = "isMissing";
	String ISNOTIN = "isNotIn";
	String ISNOTMISSING = "isNotMissing";
	String ISNOTVALID = "isNotValid";
	String ISVALID = "isValid";
	String LESSOREQUAL = "lessOrEqual";
	String LESSTHAN = "lessThan";
	String LN = "ln";
	String LN1P = "ln1p";
	String LOG10 = "log10";
	String LOWERCASE = "lowercase";
	String MATCHES = "matches";
	String MAX = "max";
	String MEDIAN = "median";
	String MIN = "min";
	String MODULO = "modulo";
	String MULTIPLY = "*";
	String NORMALCDF = "normalCDF";
	String NORMALIDF = "normalIDF";
	String NORMALPDF = "normalPDF";
	String NOT = "not";
	String NOTEQUAL = "notEqual";
	String OR = "or";
	String POW = "pow";
	String PRODUCT = "product";
	String REPLACE = "replace";
	String RINT = "rint";
	String ROUND = "round";
	String SIN = "sin";
	String SINH = "sinh";
	String SQRT = "sqrt";
	String STDNORMALCDF = "stdNormalCDF";
	String STDNORMALIDF = "stdNormalIDF";
	String STDNORMALPDF = "stdNormalPDF";
	String SUBSTRING = "substring";
	String SUBTRACT = "-";
	String SUM = "sum";
	String TAN = "tan";
	String TANH = "tanh";
	String THRESHOLD = "threshold";
	String TRIMBLANKS = "trimBlanks";
	String UPPERCASE = "uppercase";
}
